@@ -5,7 +5,9 @@ from pathlib import Path
 def add_new_track_layer(viewer, track_layers, point_size):
     num = len(track_layers)
     new_track_layers = viewer.add_points(
-        n_dimensional=True, size=point_size, name=f"track_{num}",
+        n_dimensional=True,
+        size=point_size,
+        name=f"track_{num}",
     )
     new_track_layers.mode = "ADD"
     track_layers.append(new_track_layers)
